@@ -12,7 +12,7 @@ import pickle
 
 class SerializedRedis(Redis):
     def set(self, key, value):
-        is_list_or_dict = type(value) == list or type(value) == dict
+        is_list_or_dict = isinstance(value, list) or isinstance(value, dict)
 
         if is_list_or_dict:
             super(Redis, self).set(key, pickle.dumps(value))
